@@ -97,7 +97,7 @@ PetscErrorCode LMESetUp(LME lme)
   PetscUseTypeMethod(lme,setup);
 
   /* set tolerance if not yet set */
-  if (lme->tol==(PetscReal)PETSC_DEFAULT) lme->tol = SLEPC_DEFAULT_TOL;
+  if (lme->tol==(PetscReal)PETSC_DETERMINE) lme->tol = SLEPC_DEFAULT_TOL;
 
   PetscCall(PetscLogEventEnd(LME_SetUp,lme,0,0,0));
   lme->setupcalled = 1;
@@ -269,7 +269,7 @@ PetscErrorCode LMEGetRHS(LME lme,Mat *C)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
-  PetscValidPointer(C,2);
+  PetscAssertPointer(C,2);
   *C = lme->C;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -340,7 +340,7 @@ PetscErrorCode LMEGetSolution(LME lme,Mat *X)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
-  PetscValidPointer(X,2);
+  PetscAssertPointer(X,2);
   *X = lme->X;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -378,7 +378,7 @@ PetscErrorCode LMEAllocateSolution(LME lme,PetscInt extra)
   /* allocate basis vectors */
   if (!lme->V) PetscCall(LMEGetBV(lme,&lme->V));
   if (!oldsize) {
-    if (!((PetscObject)(lme->V))->type_name) PetscCall(BVSetType(lme->V,BVSVEC));
+    if (!((PetscObject)lme->V)->type_name) PetscCall(BVSetType(lme->V,BVMAT));
     PetscCall(MatCreateVecsEmpty(lme->A,&t,NULL));
     PetscCall(BVSetSizesFromVec(lme->V,t,requested));
     PetscCall(VecDestroy(&t));
